==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/demo/grph2/uspack/uspk03.c <==
/* demo/grph2/uspack/uspk03.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__9 = 9;
static integer c__1 = 1;
static integer c__3 = 3;
static real c_b8 = 0.f;
static real c_b9 = 1.f;
static integer c__30 = 30;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Main program */ int MAIN__(void)
{
    /* Builtin functions */
    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
	    e_wsle(void), s_rsle(cilist *), e_rsle(void);

    /* Local variables */
    static doublereal a;
    static integer i__;
    static doublereal r__;
    static real y[30];
    static integer iws;
    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *);
    static real rundef;
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen), grswnd_(real 
	    *, real *, real *, real *), usgrph_(integer *, real *, real *), 
	    sgpwsn_(void);

    /* Fortran I/O blocks */
    static cilist io___5 = { 0, 6, 0, 0, 0 };
    static cilist io___6 = { 0, 5, 0, 0, 0 };


/* ---------------------------- DATA DEFINITION -------------------------- */
    r__ = .2;
    a = 3.7;
    for (i__ = 1; i__ <= 30; ++i__) {
	r__ = a * r__ * (1. - r__);
	y[i__ - 1] = r__;
/* L100: */
    }
/* ----------------------------- GRAPH ----------------------------------- */
    s_wsle(&io___5);
    do_lio(&c__9, &c__1, " WORKSTATION ID (I)  ? ;", (ftnlen)24);
    e_wsle();
    sgpwsn_();
    s_rsle(&io___6);
    do_lio(&c__3, &c__1, (char *)&iws, (ftnlen)sizeof(integer));
    e_rsle();
    glrget_("RUNDEF", &rundef, (ftnlen)6);
    gropn_(&iws);
    grfrm_();
    grswnd_(&c_b8, &c_b9, &rundef, &rundef);
    usgrph_(&c__30, &rundef, y);
    grcls_();
/* ----------------------------------------------------------------------- */
    return 0;
} /* MAIN__ */

/* Main program alias */ int uspk03_ () { MAIN__ (); return 0; }

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/demo/grph2/uspack/uspk03.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__9 = 9;
static integer c__1 = 1;
static integer c__3 = 3;
static real c_b8 = 0.f;
static real c_b9 = 1.f;
static integer c__30 = 30;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Main program */ int MAIN__(void)
{
    /* Builtin functions */
    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
	    e_wsle(void), s_rsle(cilist *), e_rsle(void);

    /* Local variables */
    static doublereal a;
    static integer i__;
    static doublereal r__;
    static real y[30];
    static integer iws;
    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *);
    static real rundef;
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen), grswnd_(real 
	    *, real *, real *, real *), usgrph_(integer *, real *, real *), 
	    sgpwsn_(void);

    /* Fortran I/O blocks */
    static cilist io___5 = { 0, 6, 0, 0, 0 };
    static cilist io___6 = { 0, 5, 0, 0, 0 };


/* ---------------------------- DATA DEFINITION -------------------------- */
    r__ = .2;
    a = 3.7;
    for (i__ = 1; i__ <= 30; ++i__) {
	r__ = a * r__ * (1. - r__);
	y[i__ - 1] = r__;
/* L100: */
    }
/* ----------------------------- GRAPH ----------------------------------- */
    s_wsle(&io___5);
    do_lio(&c__9, &c__1, " WORKSTATION ID (I)  ? ;", (ftnlen)24);
    e_wsle();
    sgpwsn_();
    s_rsle(&io___6);
    do_lio(&c__3, &c__1, (char *)&iws, (ftnlen)sizeof(integer));
    e_rsle();
    glrget_("RUNDEF", &rundef, (ftnlen)6);
    gropn_(&iws);
    grfrm_();
    grswnd_(&c_b8, &c_b9, &rundef, &rundef);
    usgrph_(&c__30, &rundef, y);
    grcls_();
/* ----------------------------------------------------------------------- */
    return 0;
} /* MAIN__ */

/* Main program alias */ int uspk03_ () { MAIN__ (); return 0; }
